@@ -47,11 +47,12 @@ from calculate.lib.utils.text import _u8
 from calculate.lib.variables.linux import LinuxDataVars, Linux
 
 from calculate.lib.cl_lang import setLocalTranslate, _
+from functools import reduce
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
 
 
-class DefaultMountPath(object):
+class DefaultMountPath():
     """
     Пути по умолчанию для монтирования образов
     """
@@ -118,7 +119,7 @@ def progressCopyFile(source, dest):
     bufsize = (100 - (size % 100) + size) / 100
     with open(source, 'rb') as infile:
         with open(dest, 'w') as outfile:
-            for i in xrange(1, 101):
+            for i in range(1, 101):
                 outfile.write(infile.read(bufsize))
                 yield i
 
@@ -128,12 +129,12 @@ class DistributiveError(Exception):
     pass
 
 
-class Distributive(object):
+class Distributive():
     """
     Distributive object. Parent object for all distributive.
     """
 
-    class Type(object):
+    class Type():
         Directory = "dir"
         Partition = "part"
         SquashFS = "squash"
@@ -319,10 +320,10 @@ class Distributive(object):
                     return False
             os.mkdir(pathname)
             return True
-        except Exception, e:
+        except Exception as e:
             raise DistributiveError(_("Failed to create the directory") +
                                     " '%s':\n%s" % (pathname, str(e)))
-        except KeyboardInterrupt, e:
+        except KeyboardInterrupt as e:
             raise DistributiveError(_("Failed to create the directory") +
                                     " '%s':\n%s" % (pathname, str(e)))
 
@@ -356,10 +357,10 @@ class Distributive(object):
     def _copytree(self, indir, outdir):
         try:
             copytree(indir, outdir, symlinks=True)
-        except Exception, e:
+        except Exception as e:
             raise DistributiveError(_("Failed to copy") + " '%s' to '%s':\n%s" \
                                     % (indir, outdir, str(e)))
-        except KeyboardInterrupt, e:
+        except KeyboardInterrupt as e:
             raise DistributiveError(_("Failed to copy") + " '%s' to '%s':\n%s" \
                                     % (indir, outdir, str(e)))
 
@@ -373,10 +374,10 @@ class Distributive(object):
             joinFrom = partial(path.join, fromdir)
             params = [cpCmd, "-x"] + \
                      (["--no-preserve=mode,ownership"] if noperm else ["-a"]) + \
-                     map(joinFrom,
-                         ifilterfalse(byfile or operator.not_,
-                                      listDirectory(fromdir))) + \
-                     [todir]
+                        [joinFrom(x) for x 
+                            in filterfalse(byfile or operator.not_,
+                                listDirectory(fromdir))] + \
+                        [todir]
             cpProcess = cpProcessProgress(*params,
                                           maxfiles=filesnum, stderr=STDOUT)
             for perc in cpProcess.progress():
@@ -385,8 +386,7 @@ class Distributive(object):
             errmes = cpProcess.read()
             # copy by one file
             if byfile:
-                percFiles = filter(byfile,
-                                   listDirectory(fromdir))
+                percFiles = [x for x in listDirectory(fromdir) if byfile(x)]             
                 if len(percFiles) > 1:
                     maxPercOnFile = 100 / len(percFiles)
                     recountPerc = \
@@ -399,7 +399,7 @@ class Distributive(object):
                                                  path.join(todir, copyfile)):
                         if callbackProgress:
                             callbackProgress(recountPerc(perc, i))
-        except Exception, e:
+        except Exception as e:
             res = False
             errmes = str(e)
         if not res:
@@ -430,7 +430,7 @@ class Distributive(object):
     def rndString(self):
         """Get random string with len 8 char"""
         return "".join([choice(string.ascii_letters + string.digits)
-                        for i in xrange(0, 8)])
+                        for i in range(0, 8)])
 
     def _getSquashNum(self, reMatch):
         if reMatch.groups()[1] and reMatch.groups()[1].isdigit():
@@ -440,9 +440,7 @@ class Distributive(object):
 
     def _getLastLive(self, directory):
         """Get last live squashfs image from directory"""
-        squashfiles = filter(lambda x: x,
-                             map(self.reLive.search,
-                                 listDirectory(directory)))
+        squashfiles = [x for x in map(self.reLive.search, listDirectory(directory)) if x]
         if squashfiles:
             return max(squashfiles, key=self._getSquashNum).group()
         return None
@@ -455,8 +453,7 @@ class Distributive(object):
             raise DistributiveError(
                 _("Failed to mount to the directory: %s\n")
                 % directory + _("Directory already mounted"))
-        mountopts_list = filter(lambda x: x,
-                                mountopts.split(" "))
+        mountopts_list = [x for x in mountopts.split(" ") if x]
         mountProcess = process('/bin/mount', file, directory, *mountopts_list,
                                stderr=STDOUT)
         if mountProcess.success():
@@ -667,7 +664,7 @@ class DirectoryDistributive(Distributive):
         :return:
         """
         if not self.system_mounted:
-            for obj in filter(lambda x: x['name'] not in skip, self.data):
+            for obj in (x for x in self.data if x['name'] not in skip):
                 target_path = path.join(self.directory, obj['target'])
                 if obj['type'] == 'bind':
                     if not path.exists(target_path):
@@ -769,7 +766,7 @@ class DirectoryDistributive(Distributive):
         return ld
 
 
-class DataPartition(object):
+class DataPartition():
     """Data partition"""
     dev = None
     mountPoint = None
@@ -789,10 +786,8 @@ class MultiPartitions:
         """Add partition in data partition list"""
         dictDataPart = reduce(lambda x, y: \
                                   x.update({y: getattr(DataPartition, y)}) or x,
-                              filter(lambda x: not x.startswith('_'),
-                                     DataPartition.__dict__), {})
-        updateAttrData = filter(lambda x: x[1] is not None,
-                                dictDataPart.items())
+                              [x for x in DataPartition.__dict__ if not x.startswith('_')], {})
+        updateAttrData = (x for x in dictDataPart.items() if x[1] is not None)
         defaultAttr = []
         for attrName, attrValue in updateAttrData:
             if not attrName in argv.keys():
@@ -803,14 +798,13 @@ class MultiPartitions:
             if notFoundAttr:
                 raise DistributiveError(_("The following attributes "
                                           "are not specified: (%s)") \
-                                        % ", ".join(
-                    map(lambda x: "DataPartition.%s" % x, notFoundAttr)))
+                                         % ", ".join(("DataPartition.%s" % x for x in notFoundAttr)))
             unnecessaryAttr = (set(dictDataPart.keys()) ^ set(argv.keys())) - \
                               set(dictDataPart.keys())
             if unnecessaryAttr:
                 raise DistributiveError(_("Failed to use attributes (%s) ") \
                                         % ", ".join(
-                    map(lambda x: "DataPartition.%s" % x, unnecessaryAttr)))
+                    ("DataPartition.%s" % x for x in unnecessaryAttr)))
         else:
             partObj = DataPartition()
             for attr, value in argv.items():
@@ -821,27 +815,27 @@ class MultiPartitions:
 
     def getSystemId(self):
         """Get systemID for change [None,82,...]"""
-        return map(lambda x: x.systemId, self.listPartitions)
+        return [x.systemId for x in self.listPartitions]
 
     def getPartitionTable(self):
         """Get systemID for change [dos,gpt,...]"""
-        return map(lambda x: x.partitionTable, self.listPartitions)
+        return [x.partitionTable for x in self.listPartitions]
 
     def getIsFormat(self):
         """Get list is format [True,...]"""
-        return map(lambda x: x.isFormat, self.listPartitions)
+        return [x.isFormat for x in self.listPartitions]
 
     def getFileSystems(self):
         """Get list filesystems ["reiserfs",...]"""
-        return map(lambda x: x.fileSystem, self.listPartitions)
+        return [x.fileSystem for x in self.listPartitions]
 
     def getPartitions(self):
         """Get list partition ["/dev/sda",...]"""
-        return map(lambda x: x.dev, self.listPartitions)
+        return [x.dev for x in self.listPartitions]
 
     def getMountPoints(self):
         """Get list mount point ["/boot",...]"""
-        return map(lambda x: x.mountPoint, self.listPartitions)
+        return [x.mountPoint for x in self.listPartitions]
 
 
 class FormatProcess(process):
@@ -854,7 +848,7 @@ class FormatProcess(process):
         self._label = label
         self.purpose = purpose
         self.compression = compression
-        super(FormatProcess, self).__init__(*self.format_command())
+        super().__init__(*self.format_command())
 
     def format_command(self):
         cmd = getProgPath(self.format_util)
@@ -1083,8 +1077,7 @@ class PartitionDistributive(Distributive):
     def postinstallMountBind(self):
         """Mount bind mount point and create mount dirs"""
         if self.multipartition and self.DirectoryObject:
-            mulipartDataBind = filter(lambda x: x[2] == "bind",
-                                      self.getMultipartData())
+            mulipartDataBind = [x for x in self.getMultipartData() if x[2] == "bind"]
             dirObj = self.DirectoryObject
             mdirectory = dirObj.directory
             for srcDir, destDir, fileSystem, isFormat, partTable \
@@ -1128,8 +1121,7 @@ class PartitionDistributive(Distributive):
             mapOpts.get(self.fileSystem,""))
         dirObj = DirectoryDistributive(mdirectory, parent=self)
         if self.multipartition:
-            mulipartDataNotBind = filter(lambda x: x[2] != "bind",
-                                         self.getMultipartData())
+            mulipartDataNotBind = (x for x in self.getMultipartData() if x[2] != "bind")
             for dev, mountPoint, fileSystem, isFormat, partTable \
                     in sorted(mulipartDataNotBind, key=lambda x: x[1]):
                 realMountPoint = None
@@ -1165,10 +1157,8 @@ class PartitionDistributive(Distributive):
                              self.multipartition.getMountPoints() + \
                              ["/"])
         # get partition which need format
-        formatPartitions = map(lambda x: (x[FS], x[DEV], x[NEWID], x[MP]),
-                               filter(
-                                   lambda x: x[NEEDFORMAT] and x[FS] != "bind",
-                                   dataPartitions))
+        formatPartitions = [(x[FS], x[DEV], x[NEWID], x[MP]) for x 
+            in dataPartitions if x[NEEDFORMAT] and x[FS] != "bind"]
         # if has separate /boot partition
         bootmp = ["/boot", "/"]
         purpose_map = {"/boot": "boot",
@@ -1193,9 +1183,8 @@ class PartitionDistributive(Distributive):
                         self.formatPartition(dev, format=fileSystem,
                                              purpose=purpose_map.get(mp, None))
         # change system id for partitions
-        changeidPartitions = map(lambda x: (x[NEWID], x[DEV], x[PARTTABLE]),
-                                 filter(lambda x: x[NEWID],
-                                        dataPartitions))
+        changeidPartitions = [(x[NEWID], x[DEV], x[PARTTABLE]) for x 
+            in dataPartitions if  x[NEWID]]
         for systemid, dev, partTable in changeidPartitions:
             self.changeSystemID(dev, systemid, partTable)
         return True
@@ -1212,8 +1201,7 @@ class PartitionDistributive(Distributive):
             raise DistributiveError(
                 _("The specified format of '%s' is not supported") % format)
         with open("/proc/swaps") as f:
-            if dev in map(lambda y: y.split(" ")[0],
-                          filter(lambda x: x.startswith("/"),f)):
+            if dev in (x.split(" ")[0] for x in f if x.startswith("/")):
                 raise DistributiveError(
                     _("Failed to format %s: this partition is used as swap") % dev)
         self._checkMount(dev)
@@ -1290,8 +1278,7 @@ class PartitionDistributive(Distributive):
     def formatSwapPartition(self, dev):
         """Format swap partition"""
         with open("/proc/swaps") as f:
-            if dev in map(lambda y: y.split(" ")[0],
-                          filter(lambda x: x.startswith("/"),f)):
+            if dev in (x.split(" ")[0] for x in f if x.startswith("/")):
                 raise DistributiveError(
                     _("Failed to execute 'mkswap %s': "
                       "the swap partition is used "
@@ -1494,7 +1481,7 @@ class ContainerDistributive(ArchiveDistributive):
         if self.exclude:
             exclude_list = list(calculate_exclude(
                 directory, exclude=self.exclude, include=self.include))
-            params += map(lambda x: "--exclude=./%s" % x, exclude_list)
+            params += ["--exclude=./%s" % x for x in exclude_list]
         params += ["."]
 
         #debug_file = "/var/calculate/tmp/rootfs.tar.xz"
@@ -1879,7 +1866,7 @@ class FlashDistributive(PartitionDistributive):
             clear_match = re.compile(
                 r"^(boot|efi|isolinux|syslinux|id.*\.uefi|"
                 "ldlinux.c32|ldlinux.sys|livecd|livecd.squashfs)$")
-            for fn in filter(clear_match.match, listDirectory(dn)):
+            for fn in [x for x in listDirectory(dn) if clear_match.match(x)]:
                 full_path = path.join(dn, fn)
                 try:
                     if path.isdir(full_path):
@@ -1890,7 +1877,7 @@ class FlashDistributive(PartitionDistributive):
                     raise DistributiveError(
                         _("Failed to remove %s") % fn)
         else:
-            super(FlashDistributive, self).performFormat()
+            super().performFormat()
 
     def getType(self):
         return _("USB flash %s") % self.partition
@@ -1923,7 +1910,7 @@ class FlashDistributive(PartitionDistributive):
             d = DirectoryDistributive(mp)
             d.no_unmount = True
             return d
-        return super(FlashDistributive, self).convertToDirectory()
+        return super().convertToDirectory()
 
     def releaseChild(self, child):
         """Umount child Directory distributive"""
@@ -1989,7 +1976,7 @@ class LayeredDistributive(Distributive):
         :param image_file: образ оригинала
         :param parent: родительский дистрибутив
         """
-        super(LayeredDistributive, self).__init__(parent=parent)
+        super().__init__(parent=parent)
         self.mdirectory = mdirectory
         self.diff_directory = diff_directory
         self.workdir = "%s-work" % self.diff_directory
