@@ -80,10 +80,8 @@ class Install(MethodsInterface):
     def canInstallGrub2(self, target):
         """Check that system has grub2 in current and installed system"""
         if self.clVars.Get('os_grub2_path'):
-            return bool(
-                filter(lambda x: (x.startswith('grub-1.99') or
-                                  x.startswith('grub-2')),
-                       listDirectory('/var/db/pkg/sys-boot')))
+            return bool([x for x in listDirectory('/var/db/pkg/sys-boot') 
+                if (x.startswith('grub-1.99') or x.startswith('grub-2'))])
         return False
 
     def prepareBoot(self, target_distr):
@@ -132,36 +130,56 @@ class Install(MethodsInterface):
         if partition_table == "dos":
             fdisk = process(fdisk_cmd, "-l", device_name)
             DEVICENUM, AFLAG = 0, 1
-            change_active = map(
-                lambda x: x[DEVICENUM],
-                filter(
-                    lambda x: (x[DEVICENUM] != partition_number and
-                               x[AFLAG] == "*" or
-                               x[DEVICENUM] == partition_number and
-                               not x[AFLAG] == "*"),
-                    list(map(
-                        lambda x: [str(x[0]), x[1][1].strip()],
-                        # enumerate partitions
-                        enumerate(filter(None, map(
-                            lambda x: x.split()[:2],
-                            # drop string before information about partitions
-                            dropwhile(
-                                lambda x: not x.lstrip().startswith(
-                                    "Device"),
-                                fdisk.readlines()))))))[1:]))
+            # change_active = map(
+            #     lambda x: x[DEVICENUM],
+            #     filter(
+            #         lambda x: (x[DEVICENUM] != partition_number and
+            #                    x[AFLAG] == "*" or
+            #                    x[DEVICENUM] == partition_number and
+            #                    not x[AFLAG] == "*"),
+            #         list(map(
+            #             lambda x: [str(x[0]), x[1][1].strip()],
+            #             # enumerate partitions
+            #             enumerate(filter(None, map(
+            #                 lambda x: x.split()[:2],
+            #                 # drop string before information about partitions
+            #                 dropwhile(
+            #                     lambda x: not x.lstrip().startswith(
+            #                         "Device"),
+            #                     fdisk.readlines()))))))[1:]))
+            change_active = [x[DEVICENUM] for x 
+                in [[str(y[0]), y[1][1].strip()] for y 
+                    in enumerate([z for z 
+                        in [o.split()[:2] for o 
+                            in dropwhile(lambda x: not x.lstrip().startswith("Device"),fdisk.readlines())] 
+                    if z])][1:] 
+                if x[DEVICENUM] != partition_number and
+                    x[AFLAG] == "*" or
+                    x[DEVICENUM] == partition_number and
+                    not x[AFLAG] == "*"]    
         else:
             parted = process(parted_cmd, "-m", device_name, "print")
             DEVICENUM, FLAGS = 0, 6
-            change_active = map(
-                lambda x: x[DEVICENUM], filter(
-                    lambda x: (x[DEVICENUM] != partition_number and
-                               boot_flag in x[FLAGS].strip(';').split(', ') or
-                               x[DEVICENUM] == partition_number and
-                               boot_flag not in
-                               x[FLAGS].strip(';').split(', ')),
-                    filter(lambda x: len(x) >= 7,
-                           map(lambda x: x.split(':'),
-                               parted.readlines()[2:]))))
+            # change_active = map(
+            #     lambda x: x[DEVICENUM], filter(
+            #         lambda x: (x[DEVICENUM] != partition_number and
+            #                    boot_flag in x[FLAGS].strip(';').split(', ') or
+            #                    x[DEVICENUM] == partition_number and
+            #                    boot_flag not in
+            #                    x[FLAGS].strip(';').split(', ')),
+            #         filter(lambda x: len(x) >= 7,
+            #                map(lambda x: x.split(':'),
+            #                    parted.readlines()[2:]))))
+            change_active = [x[DEVICENUM] for x 
+                    in [y for y 
+                        in [z.split(':') for z 
+                            in parted.readlines()[2:]] 
+                    if len(y) >= 7] 
+                if x[DEVICENUM] != partition_number and
+                    boot_flag in x[FLAGS].strip(';').split(', ') or
+                    x[DEVICENUM] == partition_number and
+                    boot_flag not in
+                    x[FLAGS].strip(';').split(', ')]
         if not change_active:
             return True
         if partition_table == "dos":
@@ -269,9 +287,9 @@ class Install(MethodsInterface):
         # если GRUB2 версии 2.00 и выше, обычная установка требует
         # параметра --target=i386-pc, иначе GRUB2 может попытаться
         # прописать себя как UEFI
-        if filter(lambda x: "2." in x,
-                  process(*traverse([chrooting,
-                          cmd_grub_install, '--version']))):
+        if [x for x 
+            in process(*traverse([chrooting, cmd_grub_install, '--version'])) 
+            if "2." in x]:
             platform = ["--target=i386-pc"]
         else:
             platform = []
@@ -639,10 +657,10 @@ class Install(MethodsInterface):
         """
         target_dir = target.getDirectory()
         source_dir = source.getDirectory()
-        for f in filter(lambda x: x.endswith('.clt'),
-                        chain(*map(lambda x: find(pathJoin(source_dir, x),
-                                                  filetype="f"),
-                                   cltpath))):
+        for f in (x for x 
+                in chain(*[find(pathJoin(source_dir, y), filetype="f") for y 
+                    in cltpath]) 
+                if x.endswith('.clt')):
             copyWithPath(f, target_dir, prefix=source_dir)
         return True
 
@@ -654,10 +672,10 @@ class Install(MethodsInterface):
                                "/root/.ssh/(id_.*|known_hosts))")
         target_dir = target.getDirectory()
         source_dir = source.getDirectory()
-        for f in filter(file_mask.search,
-                        chain(*map(lambda x: find(pathJoin(source_dir, x),
-                                                  filetype="f"),
-                                   ["/etc", "/root/.ssh"]))):
+        for f in (x for x 
+                in chain(*(find(pathJoin(source_dir, y), filetype="f") for y 
+                    in ["/etc", "/root/.ssh"])) 
+                if file_mask.search(x)):
             copyWithPath(f, target_dir, prefix=source_dir)
         return True
 
@@ -667,7 +685,7 @@ class Install(MethodsInterface):
         """
         """Get random string with len 8 char"""
         return "".join([choice(string.ascii_letters + string.digits)
-                        for i in xrange(0, 8)])
+                        for i in range(0, 8)])
 
     def _getFreeDirectory(self, directory):
         """
