@@ -26,14 +26,15 @@ from calculate.lib.utils.common import (getSupportArch, getTupleVersion,
                                         cmpVersion)
 from calculate.lib.utils.files import listDirectory, pathJoin
 from calculate.lib.variables.linux import Linux
-from calculate.install.distr import (Distributive, PartitionDistributive,
+from ..distr import (Distributive, PartitionDistributive,
                                      DirectoryDistributive, DefaultMountPath,
                                      DistributiveError, FlashDistributive,
                                      ArchiveDistributive,
                                      MultiPartitions, PxeDistributive)
 
 from calculate.lib.cl_lang import setLocalTranslate, _
-from calculate.install.fs_manager import FileSystemManager
+from ..fs_manager import FileSystemManager
+from functools import reduce, cmp_to_key
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
 
@@ -92,11 +93,10 @@ class DistroRepository(Linux):
 
     def _getAvailableShortnames(self, dirs):
         """Get available distributives shortnames"""
-        distros = filter(lambda x: x,
-                         map(self.reDistName.search,
-                             self._getAvailableDistributives(dirs)))
-        return sorted(list(set(map(lambda x: x.groupdict()['name'], distros))))
-
+        distros = [x for x 
+            in map(self.reDistName.search, self._getAvailableDistributives(dirs)) 
+            if x]
+        return sorted(list(set([x.groupdict()['name'] for x in distros])))
     def opcompareByString(self, buf):
         if buf:
             reOp = re.compile("^(!=|=|==|<=|>=|>|<)?(\d+.*)$")
@@ -160,19 +160,15 @@ class DistroRepository(Linux):
                 return [pathname]
             else:
                 # discard inner directories
-                return filter(lambda x: not path.isdir(path.join(pathname, x)),
-                              listDirectory(pathname))
+                return [x for x in listDirectory(pathname) if not path.isdir(path.join(pathname, x))]
 
         # get lists files in directories
-        allFiles = map(lambda x: map(lambda y: path.join(x, y),
-                                     listdistr(x)),
-                       dirs)
+        allFiles = [[path.join(x, y) for y in listdistr(x)] for x in dirs]
         # filter distributives
-        return filter(distfilter,
-                      # join files lists to one list
-                      reduce(lambda x, y: x + y,
-                             allFiles, []))
+                             # join files lists to one list
+        return [x for x in reduce(lambda x, y: x + y, allFiles, []) if distfilter(x)]
 
+    @staticmethod
     def extcomparator(self, *exts):
         """Compare extensions"""
         mapExts = {'iso': 0,
@@ -180,9 +176,16 @@ class DistroRepository(Linux):
                    'isodir': -2,
                    'partdir': -3,
                    'dir': -4}
-        return cmp(mapExts.get(exts[0], -4), mapExts.get(exts[1], -4))
+        
+        # return cmp(mapExts.get(exts[0], -4), mapExts.get(exts[1], -4))
+        #no cmp in python3, instead do (a > b) - (a < b) 
+        return (mapExts.get(exts[0], -4) > mapExts.get(exts[1], -4)) - \
+            (mapExts.get(exts[0], -4) < mapExts.get(exts[1], -4)) 
+        
 
-    def sortdistrfunc(self, x, y):
+
+    @staticmethod
+    def sortdistrfunc(x, y):
         """Func of comparing two distributive"""
         ver1, ver2 = x[1].get('os_linux_ver', ""), y[1].get('os_linux_ver', "")
         if ver1 and ver2 and ver1 != "0" and ver2 != "0" and ver1 != ver2:
@@ -198,7 +201,7 @@ class DistroRepository(Linux):
                 return cmp(int(ser1), int(ser2))
             ext1 = x[1].get('ext', "")
             ext2 = y[1].get('ext', "")
-            return self.extcomparator(ext1, ext2)
+            return DistroRepository.extcomparator(ext1, ext2)
 
     def getAvailableDristibutives(self, dirs, system=None, shortname=None,
                                   march=None, version=None, build=None,
@@ -209,12 +212,10 @@ class DistroRepository(Linux):
         availDistrs = self._getAvailableDistributives(dirs, system, shortname,
                                                       march, version,
                                                       build)
-        availDistrs = filter(lambda x: x[1] and "ext" in x[1] and
-                                       not x[1]["ext"] in discardType,
-                             map(lambda x: (x, self._getDistrInfo(x)),
-                                 availDistrs))
-        return map(lambda x: x[0],
-                   sorted(availDistrs, self.sortdistrfunc, reverse=True))
+        availDistrs = (x for x 
+            in [(y, self._getDistrInfo(y)) for y in availDistrs] 
+            if x[1] and "ext" in x[1] and not x[1]["ext"] in discardType)
+        return [x[0] for x in sorted(availDistrs, key=cmp_to_key(DistroRepository.sortdistrfunc), reverse=True)]
 
     def getBestDistributive(self, dirs, system=None, shortname=None, march=None,
                             version=None, build=None, discardType=()):
@@ -236,7 +237,7 @@ class DistroRepository(Linux):
                 path.join(y, x)),
             listDirectory(y)),
                           existsdirs, [])
-        listimgs = filter(lambda x: x, listimgs)
+        listimgs = [x for x in listimgs if x]
         if listimgs:
             return max(listimgs, key=keyfunc).group()
         return ""
@@ -382,9 +383,7 @@ class VariableClImageFilename(DistroRepository, Variable):
                                                  discardType=discardType)
         if self.wasSet and not self.value in distros:
             distros.append(self.value)
-        return sorted(map(lambda x: (
-            x, self.humanImageName(self._getDistrInfo(x), x)), distros),
-                      key=itemgetter(1))
+        return sorted(((x, self.humanImageName(self._getDistrInfo(x), x)) for x in distros), key=itemgetter(1))
 
 
 class VariableClImageArchMachine(DistroRepository, Variable):
@@ -499,21 +498,17 @@ class VariableClImagePath(ReadonlyVariable):
                     livedistr = ['/run/initramfs/squashfs',
                                  '/run/initramfs/live',
                                  '/mnt/cdrom']
-                livedistr = filter(listDirectory,
-                                   livedistr)[:1]
+                livedistr = [x for x in livedistr if listDirectory(x)][:1]
         else:
             livedistr = []
         # search all partition for source installation distributive
         rootDev = self.Get('os_install_root_dev')
-        livedistr += \
-            map(lambda x: x[0],
-                filter(lambda x: " live" in x[1] and x[0] != rootDev,
-                       zip(self.Get('os_disk_dev'),
-                           self.Get('os_disk_content'))))
+        livedistr = [x[0] for x 
+            in zip(self.Get('os_disk_dev'), self.Get('os_disk_content')) 
+            if " live" in x[1] and x[0] != rootDev]
         # add to standard path 
-        return filter(path.exists,
-                      ['/var/calculate/remote/linux',
-                       '/var/calculate/linux'] + livedistr)
+        return [x for x in ['/var/calculate/remote/linux',
+                '/var/calculate/linux'] + livedistr if path.exists(x)]
 
 
 class VariableClSource(ReadonlyVariable):
