@@ -53,9 +53,8 @@ class VariableOsInstallLinguas(LocaleVariable):
 
     def get(self):
         def get_linguas(lines):
-            linguas = map(lambda x: x.strip().rpartition('=')[-1].strip('"\''),
-                          filter(lambda x: x.startswith("LINGUAS="),
-                                 lines))
+            linguas = [x.strip().rpartition('=')[-1].strip('"\'') for x 
+                in lines if x.startswith("LINGUAS=")]
             return linguas[-1] if linguas else ""
 
         makeconf = '/etc/make.conf'
@@ -69,11 +68,8 @@ class VariableOsInstallLinguas(LocaleVariable):
         # get linguas from make.conf, emerge --info or default
         curlanguage = self.Get('os_install_locale_language')
         return get_linguas(readLinesFile(makeconf)) or \
-               " ".join(filter(lambda x: x == "en" or x == curlanguage,
-                               get_linguas(
-                                   process(
-                                       *infocommand).readlines() or "").split())) or \
-               defaultLinguas
+               " ".join((x for x in get_linguas(process(*infocommand).readlines() or "").split() if x == "en" or x == curlanguage)) or defaultLinguas
+
 
 
 class VariableOsInstallLocaleConsolefont(LocaleVariable):
@@ -137,8 +133,8 @@ class VariableOsInstallLocaleLang(LocaleVariable):
         return self.Get('os_locale_lang')
 
     def choice(self):
-        return zip(self.Get('os_lang'),
-                   map(str, self.Get('os_lang', humanreadable=True)))
+        return list(zip(self.Get('os_lang'),
+                   map(str, self.Get('os_lang', humanreadable=True))))
 
 
 class VariableOsInstallLocaleKeyboardLayout(LocaleVariable):
@@ -164,8 +160,8 @@ class VariableOsInstallLocaleKeyboardLayout(LocaleVariable):
             return self.Get('os_locale_keyboard_layout')
 
     def choice(self):
-        return zip(self.Get('os_keyboard_layout'),
-                   map(str, self.Get('os_keyboard_layout', humanreadable=True)))
+        return list(zip(self.Get('os_keyboard_layout'),
+                   map(str, self.Get('os_keyboard_layout', humanreadable=True))))
 
 
 class VariableOsInstallLocaleLanguage(LocaleVariable):
@@ -337,11 +333,9 @@ class VariableOsInstallClockTimezone(LocaleVariable):
 
         try:
             lang = self.Get(self.locale_varname).split('_')[1]
-            nativeTZ = map(lambda x: x.encode('utf-8'),
-                           country_timezones[lang])
+            nativeTZ = [x.encode('utf-8') for x in country_timezones[lang]]
             source = nativeTZ + ["---"] + \
-                     sorted(filter(lambda x: not x in nativeTZ, source),
-                            key=sortkey)
+                    sorted([x for x in source if not x in nativeTZ], key=sortkey) 
         except (KeyError, IndexError) as e:
             pass
         return list(self.generateComments(source))
