@@ -14,12 +14,13 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import sys
 
 from calculate.lib.datavars import VariableError, DataVarsError
-from calculate.install.distr import DistributiveError
+from .distr import DistributiveError
 
-import install
+from . import install
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate, _
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
@@ -27,8 +28,8 @@ __ = getLazyLocalTranslate(_)
 
 from calculate.core.server.func import WsdlBase
 from calculate.lib.utils.partition import VolumesError
-from calculate.install.utils.cl_install import ClInstallAction
-from calculate.install.utils.cl_setup import (
+from .utils.cl_install import ClInstallAction
+from .utils.cl_setup import (
     ClSetupLocaleAction, ClSetupVideoAction, ClSetupSystemAction,
     ClSetupBootAction, ClSetupNetworkAction, ClSetupAudioAction,
     ClSetupSessionAction, ClSetupThemesAction)
